@@ -10,12 +10,12 @@
 #' @section Sass caching and precompilation:
 #'
 #' If Shiny Developer Mode is enabled (by setting `options(shiny.devmode =
-#' TRUE)` or calling `shiny::devmode(TRUE)`), both \pkg{sass} caching and \pkg{bslib}
-#' precompilation are disabled by default; that is, a call to
+#' TRUE)` or calling `shiny::devmode(TRUE)`), both \pkg{sass} caching and
+#' \pkg{bslib} precompilation are disabled by default; that is, a call to
 #' `bs_theme_dependencies(theme)` expands to `bs_theme_dependencies(theme, cache
-#' = F, precompiled = F)`). This is useful for local development as
-#' enabling caching/precompilation may produce incorrect results if local
-#' changes are made to bslib's source files.
+#' = F, precompiled = F)`). This is useful for local development as enabling
+#' caching/precompilation may produce incorrect results if local changes are
+#' made to bslib's source files.
 #'
 #' @inheritParams bs_theme_update
 #' @param sass_options a [sass::sass_options()] object.
@@ -24,25 +24,24 @@
 #'   precompiled CSS file for the [theme_version()].  If `precompiled = TRUE`
 #'   and a precompiled CSS file exists for the theme object, it will be fetched
 #'   immediately and not compiled. At the moment, we only provide precompiled
-#'   CSS for "stock" builds of Bootstrap (i.e., no theming additions, bootswatch
+#'   CSS for "stock" builds of Bootstrap (i.e., no theming additions, Bootswatch
 #'   themes, or non-default `sass_options`).
 #' @inheritParams sass::sass
 #'
-#' @return a list of HTML dependencies containing Bootstrap CSS, Bootstrap
-#'   JavaScript, and `jquery`. This list may contain additional HTML
+#' @return Returns a list of HTML dependencies containing Bootstrap CSS,
+#'   Bootstrap JavaScript, and `jquery`. This list may contain additional HTML
 #'   dependencies if bundled with the `theme`.
 #'
 #' @export
-#' @seealso [bs_theme()], [bs_dependency()]
-#' @examples
+#' @family Bootstrap theme functions
+#'
+#' @examplesIf rlang::is_interactive()
 #'
 #' # Function to preview the styling a (primary) Bootstrap button
 #' library(htmltools)
 #' button <- tags$a(class = "btn btn-primary", href = "#", role = "button", "Hello")
 #' preview_button <- function(theme) {
-#'   if (interactive()) {
-#'     browsable(tags$body(bs_theme_dependencies(theme), button))
-#'   }
+#'   browsable(tags$body(bs_theme_dependencies(theme), button))
 #' }
 #'
 #' # Latest Bootstrap
@@ -61,101 +60,129 @@ bs_theme_dependencies <- function(
   jquery = jquerylib::jquery_core(3),
   precompiled = get_precompiled_option("bslib.precompiled", default = TRUE)
 ) {
-
   theme <- as_bs_theme(theme)
   version <- theme_version(theme)
 
   if (isTRUE(version >= 5)) {
-    shiny_version <- "1.6.0.9001"
-    msg <- sprintf("`bs_theme(version = 5)` is designed to work with shiny %s or higher", shiny_version)
-    if (isNamespaceLoaded("shiny") && !is_installed("shiny", shiny_version)) warning(msg, call. = FALSE)
-    setHook(packageEvent("shiny", "onLoad"), function(...) {
-      if (!is_installed("shiny", shiny_version)) warning(msg, call. = FALSE)
-    })
+    register_runtime_package_check("`bs_theme(version = 5)`", "shiny", "1.7.0")
   }
 
   if (is.character(cache)) {
     cache <- sass_cache_get_dir(cache)
   }
 
-  out_file <- NULL
-  # Look for a precompiled css file if user asks for it AND the default options
-  # are used.
-  if (precompiled &&
-      identical(sass_options, sass_options(output_style = "compressed")))
-  {
-    precompiled_css <- precompiled_css_path(theme)
-    if (!is.null(precompiled_css)) {
-      out_dir <- file.path(tempdir(), paste0("bslib-precompiled-", version))
-      if (!dir.exists(out_dir)) {
-        dir.create(out_dir)
-      }
-      out_file <- file.path(out_dir, basename(precompiled_css))
-      file.copy(precompiled_css, out_file)
+  out_file <- maybe_precompiled_css(theme, sass_options, precompiled)
 
-      # Usually sass() would handle file_attachments and dependencies,
-      # but we need to do this manually
-      out_file <- attachDependencies(out_file, htmlDependencies(as_sass(theme)))
-      write_file_attachments(
-        as_sass_layer(theme)$file_attachments,
-        out_dir
-      )
-    }
-  }
-
-  # If precompiled css not found, compile normally.
   if (is.null(out_file)) {
-
-    contrast_warn <- get_shiny_devmode_option(
-      "bslib.color_contrast_warnings",
-      default = FALSE,
-      devmode_default = TRUE,
-      devmode_message = paste(
-        "Enabling warnings about low color contrasts found inside `bslib::bs_theme()`.",
-        "To suppress these warnings, set `options(bslib.color_contrast_warnings = FALSE)`"
-      )
-    )
-    theme <- bs_add_variables(theme, "color-contrast-warnings" = contrast_warn)
-
-    out_file <- sass(
-      input = theme,
-      options = sass_options,
-      output = output_template(basename = "bootstrap", dirname = "bslib-"),
-      cache = cache,
-      write_attachments = TRUE,
-      cache_key_extra = list(
-        get_exact_version(version),
-        get_package_version("bslib")
-      )
-    )
+    out_file <- sass_compile_theme(theme, sass_options, cache)
   }
 
-  out_file_dir <- dirname(out_file)
-
-  js_files <- bootstrap_javascript(version)
-  js_map_files <- bootstrap_javascript_map(version)
-  success_js_files <- file.copy(c(js_files, js_map_files), out_file_dir, overwrite = TRUE)
-  if (any(!success_js_files)) {
-    warning("Failed to copy over bootstrap's javascript files into the htmlDependency() directory.")
-  }
-
-  htmltools::resolveDependencies(c(
-    if (inherits(jquery, "html_dependency")) list(jquery) else jquery,
-    list(
-      htmlDependency(
-        name = "bootstrap",
-        version = get_exact_version(version),
-        src = out_file_dir,
-        stylesheet = basename(out_file),
-        script = basename(js_files),
-        all_files = TRUE, # include font and map files
-        meta = list(viewport = "width=device-width, initial-scale=1, shrink-to-fit=no")
-      )
-    ),
-    htmlDependencies(out_file)
-  ))
+  htmltools::resolveDependencies(
+    c(
+      if (inherits(jquery, "html_dependency")) list(jquery) else jquery,
+      list(
+        htmlDependency(
+          name = "bootstrap",
+          version = get_exact_version(version),
+          src = dirname(out_file),
+          stylesheet = basename(out_file),
+          script = basename(bootstrap_javascript(version)),
+          all_files = TRUE, # include font and map files
+          meta = list(
+            viewport = "width=device-width, initial-scale=1, shrink-to-fit=no"
+          )
+        )
+      ),
+      htmlDependencies(out_file)
+    )
+  )
 }
 
+maybe_precompiled_css <- function(theme, sass_options, precompiled) {
+  if (!precompiled) {
+    return()
+  }
+  if (!identical(sass_options, sass_options(output_style = "compressed"))) {
+    return()
+  }
+
+  precompiled_css <- precompiled_css_path(theme)
+  if (is.null(precompiled_css)) {
+    return()
+  }
+
+  version <- theme_version(theme)
+  bs_js_hash <- rlang::hash_file(bootstrap_javascript(version))
+  out_dir <- file.path(
+    tempdir(),
+    sprintf("bslib-precompiled-%s-%s", version, bs_js_hash)
+  )
+
+  out_file <- file.path(out_dir, basename(precompiled_css))
+  out_file <- attachDependencies(out_file, htmlDependencies(as_sass(theme)))
+
+  if (dir.exists(out_dir)) {
+    # We've already copied all the files for this precompiled theme, there's no
+    # need to copy them again.
+    return(out_file)
+  }
+
+  dir.create(out_dir)
+  file.copy(precompiled_css, out_file)
+
+  # Usually sass() would handle file_attachments and dependencies,
+  # but we need to do this manually
+  write_file_attachments(
+    as_sass_layer(theme)$file_attachments,
+    out_dir
+  )
+
+  bootstrap_javascript_copy_assets(version, dirname(out_file))
+
+  out_file
+}
+
+sass_compile_theme <- function(theme, sass_options, sass_cache) {
+  version <- theme_version(theme)
+
+  contrast_warn <- get_shiny_devmode_option(
+    "bslib.color_contrast_warnings",
+    default = FALSE,
+    devmode_default = TRUE,
+    devmode_message = paste(
+      "Enabling warnings about low color contrasts found inside `bslib::bs_theme()`.",
+      "To suppress these warnings, set `options(bslib.color_contrast_warnings = FALSE)`"
+    )
+  )
+  theme <- bs_add_variables(theme, "color-contrast-warnings" = contrast_warn)
+
+  out_file <- sass(
+    input = theme,
+    options = sass_options,
+    output = output_template(basename = "bootstrap", dirname = "bslib-"),
+    cache = sass_cache,
+    write_attachments = TRUE,
+    cache_key_extra = list(
+      get_exact_version(version),
+      get_package_version("bslib")
+    )
+  )
+
+  bootstrap_javascript_copy_assets(version, dirname(out_file))
+
+  out_file
+}
+
+bootstrap_javascript_copy_assets <- function(version, to) {
+  js_files <- bootstrap_javascript(version)
+  js_map_files <- bootstrap_javascript_map(version)
+  success_js_files <- file.copy(c(js_files, js_map_files), to, overwrite = TRUE)
+  if (any(!success_js_files)) {
+    warning(
+      "Failed to copy over bootstrap's javascript files into the htmlDependency() directory."
+    )
+  }
+}
 
 #' Themeable HTML components
 #'
@@ -165,7 +192,7 @@ bs_theme_dependencies <- function(
 #' variables, functions, and/or mixins (i.e., stuff inside of `theme`).
 #' `bs_dependencies()` makes it a bit easier to create themeable components by
 #' compiling [sass::sass()] (`input`) together with Bootstrap Sass inside of a
-#' `theme`, and packaging up the result into an [htmlDependency()].
+#' `theme`, and packaging up the result into an [htmltools::htmlDependency()].
 #'
 #' Themable components can also be  _dynamically_ themed inside of Shiny (i.e.,
 #' they may be themed in 'real-time' via [bs_themer()], and more generally,
@@ -186,16 +213,25 @@ bs_theme_dependencies <- function(
 #' @param .sass_args A list of additional arguments to pass to
 #'   [sass::sass_partial()].
 #' @inheritParams htmltools::htmlDependency
-#' @references
-#' <https://rstudio.github.io/bslib/articles/custom-components.html>
 #'
+#' @references
+#'   * [Theming: Custom components](https://rstudio.github.io/bslib/articles/custom-components/index.html)
+#'     gives a tutorial on creating a dynamically themable custom component.
 #'
 #' @return `bs_dependency()` returns an [htmltools::htmlDependency()] and
 #'   `bs_dependency_defer()` returns an [htmltools::tagFunction()]
+#'
+#' @family Bootstrap theme functions
 #' @export
-bs_dependency <- function(input = list(), theme, name, version,
-  cache_key_extra = NULL, .dep_args = list(), .sass_args = list())
-{
+bs_dependency <- function(
+  input = list(),
+  theme,
+  name,
+  version,
+  cache_key_extra = NULL,
+  .dep_args = list(),
+  .sass_args = list()
+) {
   sass_args <- c(
     list(
       rules = input,
@@ -224,19 +260,25 @@ bs_dependency <- function(input = list(), theme, name, version,
   }
 
   if ("package" %in% names(.dep_args)) {
-    warning("`package` won't have any effect since `src` must be an absolute path")
+    warning(
+      "`package` won't have any effect since `src` must be an absolute path"
+    )
   }
 
   script <- .dep_args[["script"]]
   if (length(script)) {
     if (basename(outfile) %in% basename(script)) {
-      stop("`script` file basename(s) must all be something other than ", basename(outfile))
+      stop(
+        "`script` file basename(s) must all be something other than ",
+        basename(outfile)
+      )
     }
     success <- file.copy(script, dirname(outfile), overwrite = TRUE)
     if (!all(success)) {
       stop(
         "Failed to copy the following script(s): ",
-        paste(script[!success], collapse = ", "), ".\n\n",
+        paste(script[!success], collapse = ", "),
+        ".\n\n",
         "Make sure script are absolute path(s)."
       )
     }
@@ -246,21 +288,20 @@ bs_dependency <- function(input = list(), theme, name, version,
   do.call(htmlDependency, c(dep_args, .dep_args))
 }
 
+#' @rdname bs_dependency
 #' @param func a _non-anonymous_ function, with a _single_ argument.
 #'   This function should accept a [bs_theme()] object and return a single
-#'   [htmlDependency()], a list of them, or `NULL`.
+#'   [htmltools::htmlDependency()], a list of them, or `NULL`.
 #' @param memoise whether or not to memoise (i.e., cache) `func` results for a
 #'   short period of time. The default, `TRUE`, can have large performance
 #'   benefits when many instances of the same themable widget are rendered. Note
 #'   that you may want to avoid memoisation if `func` relies on side-effects
 #'   (e.g., files on-disk) that need to change for each themable widget
 #'   instance.
+#'
 #' @export
 #'
-#' @examples
-#'
-#' \dontrun{
-#'
+#' @examplesIf rlang::is_interactive()
 #' myWidgetVersion <- "1.2.3"
 #'
 #' myWidgetDependency <- function() {
@@ -310,9 +351,6 @@ bs_dependency <- function(input = list(), theme, name, version,
 #'     myWidgetDependency()
 #'   )
 #' }
-#' }
-#'
-#' @rdname bs_dependency
 bs_dependency_defer <- function(func, memoise = TRUE) {
   # func() most likely calls stuff like sass_file() and bs_dependency() ->
   # sass_partial() -> sass() (e.g., see example section above) Even though
@@ -352,18 +390,26 @@ bs_dependency_defer <- function(func, memoise = TRUE) {
 }
 
 as_bs_theme <- function(theme) {
-  if (is_bs_theme(theme)) return(theme)
+  if (is_bs_theme(theme)) {
+    return(theme)
+  }
 
   # This is a historical artifact that should happen
   if (is_sass_bundle(theme) || inherits(theme, "sass_layer")) {
-    stop("`theme` cannot be a `sass_bundle()` or `sass_layer()` (use `bs_bundle()` to add a bundle)")
+    stop(
+      "`theme` cannot be a `sass_bundle()` or `sass_layer()` (use `bs_bundle()` to add a bundle)"
+    )
   }
 
   # NULL means default Bootstrap
-  if (is.null(theme)) return(bs_theme())
+  if (is.null(theme)) {
+    return(bs_theme())
+  }
 
   # For example, `bs_theme_dependencies(theme = 4)`
-  if (is.numeric(theme)) return(bs_theme(version = theme))
+  if (is.numeric(theme)) {
+    return(bs_theme(version = theme))
+  }
 
   # For example, `bs_theme_dependencies(theme = 'bootswatch@version')`
   if (is_string(theme)) {
