@@ -1,5 +1,7 @@
-get_current_session <- function(require_active = TRUE, call = rlang::caller_env()) {
-
+get_current_session <- function(
+  require_active = TRUE,
+  call = rlang::caller_env()
+) {
   session <- if (isNamespaceLoaded("shiny")) {
     shiny::getDefaultReactiveDomain()
   }
@@ -18,11 +20,15 @@ get_current_session <- function(require_active = TRUE, call = rlang::caller_env(
   session
 }
 
-
 has_valid_reactive_context <- function(session) {
-  if (is.null(session)) return(FALSE)
-  if (!"getCurrentTheme" %in% names(session)) return(FALSE)
-  hasReactiveContext <- getFromNamespace("hasCurrentContext", "shiny") %||% function() FALSE
+  if (is.null(session)) {
+    return(FALSE)
+  }
+  if (!"getCurrentTheme" %in% names(session)) {
+    return(FALSE)
+  }
+  hasReactiveContext <- getFromNamespace("hasCurrentContext", "shiny") %||%
+    function() FALSE
   hasReactiveContext()
 }
 
@@ -30,7 +36,6 @@ get_current_theme <- function() {
   if (isNamespaceLoaded("shiny")) shiny::getCurrentTheme()
 }
 
-
 # Shiny internal funcs needed for nav_panel() (i.e., tabPanel()) logic
 
 processDeps <- function(...) {
@@ -50,11 +55,17 @@ getCurrentThemeVersion <- function() {
 
 # Copy of shiny:::anyNamed()
 anyNamed <- function(x) {
-  if (length(x) == 0)
+  if (length(x) == 0) {
     return(FALSE)
+  }
   nms <- names(x)
-  if (is.null(nms))
+  if (is.null(nms)) {
     return(FALSE)
+  }
   any(nzchar(nms))
 }
 
+
+shiny_input_label <- function(id, label = NULL) {
+  getFromNamespace("shinyInputLabel", "shiny")(id, label)
+}
