@@ -4,7 +4,13 @@
 #  %||% is_string
 #  read_utf8
 
-switch_version <- function(version, five = default, four = default, three = default, default = NULL) {
+switch_version <- function(
+  version,
+  five = default,
+  four = default,
+  three = default,
+  default = NULL
+) {
   if (is_bs_theme(version)) {
     version <- theme_version(version)
   }
@@ -14,23 +20,35 @@ switch_version <- function(version, five = default, four = default, three = defa
     version <- "4"
   }
   switch(
-    version, `5` = five, `4` = four, `3` = three,
+    version,
+    `5` = five,
+    `4` = four,
+    `3` = three,
     stop("Didn't recognize Bootstrap version: ", version, call. = FALSE)
   )
 }
 
 get_exact_version <- function(version) {
-  switch_version(version, five = version_bs5, four = version_bs4, three = version_bs3)
+  switch_version(
+    version,
+    five = version_bs5,
+    four = version_bs4,
+    three = version_bs3
+  )
 }
 
 path_inst <- function(...) {
   files <- system_file(..., package = "bslib")
   files_found <- files != ""
-  if (all(files_found)) return(files)
+  if (all(files_found)) {
+    return(files)
+  }
 
   files_not_found <- file.path(...)[!files_found]
   stop(
-    "bslib file not found: '", files_not_found, "'",
+    "bslib file not found: '",
+    files_not_found,
+    "'",
     call. = FALSE
   )
 }
@@ -47,14 +65,18 @@ is_hosted_app <- function() {
 }
 
 is_shiny_runtime <- function() {
-  if (!is_installed("knitr")) return(FALSE)
+  if (!is_installed("knitr")) {
+    return(FALSE)
+  }
   isTRUE(grepl("^shiny", knitr::opts_knit$get("rmarkdown.runtime")))
 }
 
 register_runtime_package_check <- function(feature, pkg, version) {
   msg <- sprintf(
     "%s is designed to work with %s %s or higher",
-    feature, pkg, version
+    feature,
+    pkg,
+    version
   )
 
   if (isNamespaceLoaded(pkg) && !is_installed(pkg, version)) {
@@ -75,7 +97,7 @@ add_class <- function(x, y) {
 }
 
 dropNulls <- function(x) {
-  x[!vapply(x, is.null, FUN.VALUE=logical(1))]
+  x[!vapply(x, is.null, FUN.VALUE = logical(1))]
 }
 
 names2 <- function(x) {
@@ -83,7 +105,9 @@ names2 <- function(x) {
 }
 
 any_unnamed <- function(x) {
-  if (length(x) == 0) return(FALSE)
+  if (length(x) == 0) {
+    return(FALSE)
+  }
   nms <- names(x)
   is.null(nms) || !all(nzchar(nms))
 }
@@ -132,13 +156,41 @@ rename2 <- function(x, ...) {
 # Get an accessible color contrast for a specified bg_color
 # (and return NULL+warn on failure)
 get_color_contrast <- function(bg_color) {
-  # Use a specific name that won't clash with other variables
-  nm <- "__bslib-custom-bg-color__"
-  theme <- bs_add_variables(bs_theme(), !!nm := bg_color)
+  utils_layer <- sass::sass_layer(
+    functions = sass::sass_file(
+      path_inst("sass-utils", "color-contrast.scss")
+    ),
+    defaults = c(
+      "$black: #000000;",
+      "$white: #FFFFFF;"
+    ),
+    rules = sprintf(
+      "._ {--RET: #{color-contrast(%s)}}",
+      bg_color
+    )
+  )
+
   tryCatch(
-    bs_get_contrast(theme, nm)[[1]],
-    error = function(e) {
-      warning("Failed to compute a contrasting color for '", bg_color, "'", call. = FALSE)
+    {
+      css <- sass::sass(
+        utils_layer,
+        cache_key_extra = get_package_version("bslib"),
+        # Don't listen to global Sass options so we can be sure
+        # that stuff like source maps won't be included
+        options = sass::sass_options(source_map_embed = FALSE)
+      )
+      # example: css <- "._ {\n  --RET: #fff;\n}"
+      # we'll split to get value:     ^     ^
+      ret <- strsplit(css, "--RET:")[[1]][2]
+      trimws(strsplit(ret, ";")[[1]][1])
+    },
+    error = function(err) {
+      warning(
+        "Failed to compute a contrasting color for '",
+        bg_color,
+        "'",
+        call. = FALSE
+      )
       NULL
     }
   )
